from bookcut.mirror_checker import main as mirror_checker
from bookcut.downloader import pathfinder
from bs4 import BeautifulSoup as Soup
import mechanize
import pandas as pd
import os
import requests
from tqdm import tqdm


def search_downloader(file, href):
    response = requests.get(href, stream=True)
    total_size = int(response.headers.get('content-length'))
    inMb = total_size / 1000000
    inMb = round(inMb, 2)
    filename = file
    print("\nDownloading...\n", "Total file size:", inMb, 'MB')

    path = pathfinder()

    filename = os.path.join(path, filename)
    # progress bar
    buffer_size = 1024
    progress = tqdm(response.iter_content(buffer_size), f"{file}",
                    total=total_size, unit="B", unit_scale=True,
                    unit_divisor=1024)
    with open(filename, "wb") as f:
        for data in progress:
            # write data read to the file
            f.write(data)
            # update the progress bar manually
            progress.update(len(data))
    print("================================\nFile saved as:", filename)


def link_finder(link,mirror_used):
    page = requests.get(link)
    soup = Soup(page.content, 'html.parser')
    searcher = [a['href'] for a in soup.find_all(href=True) if a.text]
    filename = soup.find('input')['value']
    if searcher[0].startswith('http') is False:
        searcher[0] = mirror_used + searcher[0]
    results = [filename, searcher[0]]
    return results


def search(term):
    # This function is used when searching to LibGen with the command
    # bookcut search -t "keyword"

    url = mirror_checker()
    if url is not None:
        br = mechanize.Browser()
        br.set_handle_robots(False)   # ignore robots
        br.set_handle_refresh(False)  #
        br.addheaders = [('User-agent', 'Firefox')]

        br.open(url)
        br.select_form('libgen')
        input_form = term
        br.form['req'] = input_form
        ac = br.submit()
        html_from_page = ac
        soup = Soup(html_from_page, 'html.parser')
        table = soup.find_all('table')[2]

        table_data = []
        mirrors = []
        extensions = []

        for i in table:
            j = 0
            try:
                td = i.find_all('td')
                for tr in td:
                    # scrape mirror links
                    if j == 9:
                        temp = tr.find('a', href=True)
                        mirrors.append(temp['href'])
                    j = j + 1
                row = [tr.text for tr in td]
                table_data.append(row)
                extensions.append(row[8])

            except:
                pass

        # Clean result page
        for j in table_data:
            j.pop(0)
            del j[8:15]
        headers = ['Author(s)', 'Title', 'Publisher', 'Year', 'Pages',
                   'Language', 'Size', 'Extension']

        try:
            tabular = pd.DataFrame(table_data)
            tabular.index += 1
            tabular.columns = headers
            print(tabular)
            choices = []
            temp = len(mirrors) + 1
            for i in range(1, temp):
                choices.append(str(i))
            choices.append('C')
            choices.append('c')
            while True:
                tell_me = str(input('\n\nPlease enter a number from 1 to {number}'
                                    ' to download a book or press "C" to abort'
                                    ' search: '.format(number=len(extensions))))
                if tell_me in choices:
                    if tell_me == 'C' or tell_me == 'c':
                        print("Aborted!")
                        return None
                    else:
                        c = int(tell_me) - 1
                        results = [mirrors[c], extensions[c]]
                        return results
        except ValueError:
            print('\nNo results found or bad Internet connection.')
            print('Please,try again.')
            return None
    else:
        print('\nNo results found or bad Internet connection.')
        print('Please,try again.')


def single_search():
    def search(term):
        # This function is used when searching to LibGen with the command
        # bookcut search -t "keyword"

        url = mirror_checker()
        if url is not None:
            br = mechanize.Browser()
            br.set_handle_robots(False)   # ignore robots
            br.set_handle_refresh(False)  #
            br.addheaders = [('User-agent', 'Firefox')]

            br.open(url)
            br.select_form('libgen')
            input_form = term
            br.form['req'] = input_form
            ac = br.submit()
            html_from_page = ac
            soup = Soup(html_from_page, 'html.parser')
            table = soup.find_all('table')[2]

            table_data = []
            mirrors = []
            extensions = []

            for i in table:
                j = 0
                try:
                    td = i.find_all('td')
                    for tr in td:
                        # scrape mirror links
                        if j == 9:
                            temp = tr.find('a', href=True)
                            mirrors.append(temp['href'])
                        j = j + 1
                    row = [tr.text for tr in td]
                    table_data.append(row)
                    extensions.append(row[8])

                except:
                    pass

            # Clean result page
            for j in table_data:
                j.pop(0)
                del j[8:15]
            headers = ['Author(s)', 'Title', 'Publisher', 'Year', 'Pages',
                       'Language', 'Size', 'Extension']

            try:
                tabular = pd.DataFrame(table_data)
                tabular.index += 1
                tabular.columns = headers
                print(tabular)
                choices = []
                temp = len(mirrors) + 1
                for i in range(1, temp):
                    choices.append(str(i))
                choices.append('C')
                choices.append('c')
                while True:
                    tell_me = str(input('\n\nPlease enter a number from 1 to {number}'
                                        ' to download a book or press "C" to abort'
                                        ' search: '.format(number=len(extensions))))
                    if tell_me in choices:
                        if tell_me == 'C' or tell_me == 'c':
                            print("Aborted!")
                            return None
                        else:
                            c = int(tell_me) - 1
                            print(mirrors[c], "   ", extensions[c])
                            results = [mirrors[c], extensions[c]]
                            return results
            except ValueError:
                print('\nNo results found or bad Internet connection.')
                print('Please,try again.')
                return None
        else:
            print('\nNo results found or bad Internet connection.')
            print('Please,try again.')


if __name__ == '__main__':
    search(input('Term: '))



import requests
from tqdm import tqdm
import os
from bs4 import BeautifulSoup as Soup


def downloading(link, name, author, file, destination_folder, type):
    '''finds the first available book and sends the link to file_downloader '''
    page = requests.get(link)
    soup = Soup(page.content, 'html.parser')

    searcher = [a['href'] for a in soup.find_all(href=True) if a.text]
    searcher_link = searcher[0]
    if searcher_link.startswith('http') is False:
        until_dot = link.split('//')
        searcher_link = until_dot[0] + '//' + until_dot[1] + searcher_link
    file_downloader(searcher_link, name, author, file, destination_folder, type)


def file_downloader(href, name, author, file, destination_folder, type):
    '''Downloads the book file to users folder'''
    response = requests.get(href, stream=True)
    total_size = int(response.headers.get('content-length'))
    inMb = total_size / 1000000
    inMb = round(inMb, 2)
    print("\nDownloading...", "\nTotal file size:", inMb, 'MB')

# Folder to download books
    filename = file
    if filename != "":
        pass
    else:
        filename = name + ' - ' + author + type
    path = destination_folder

    filename = os.path.join(path, filename)

    try:
        with open(filename, 'wb') as f:
            ''' For progress bar '''
            with tqdm(total=total_size, unit='iB',
                      unit_scale=True) as pbar:
                for ch in response.iter_content(chunk_size=1024):
                    if ch:
                        f.write(ch)
                        pbar.update(len(ch))

        print("================================\nFile saved as:", filename)
    except FileNotFoundError:
        print("ERROR! Is the destination folder exists? ")


def pathfinder():
    path = os.path.expanduser('~/Documents/BookCut')
    if os.path.isdir(path):
        pass
    else:
        os.makedirs(path)
    return path



from bookcut.mirror_checker import main as mirror_checker
import mechanize
from bs4 import BeautifulSoup as Soup
from bookcut.libgen import file_name
from click import confirm
from bookcut.downloader import downloading


def book_find(title, author, publisher, destination, extension, force, libgenurl):
    try:
        book = Booksearch(title, author, publisher, type, libgenurl)
        result = book.search()
        extensions = result['extensions']
        tb = result['table_data']
        mirrors = result['mirrors']
        file_details = book.give_result(extensions, tb, mirrors, extension)
        if file_details is not None:
            book.cursor(file_details['url'], destination,
                        file_details['file'], force)
    except TypeError:
        # TODO add logger error
        pass


class Booksearch:
    ''' searching libgen original page and returns book details and mirror link'''

    def __init__(self, title, author, publisher, filetype, libgenurl):
        self.title = title
        self.author = author
        self.publisher = publisher
        self.filetype = filetype
        self.mirror = None
        self.libgenurl = libgenurl

    def search(self):
        ''' searching libgen and returns table data, extensions and links'''
        br = mechanize.Browser()
        br.set_handle_robots(False)   # ignore robots
        br.set_handle_refresh(False)  #
        br.addheaders = [('User-agent', 'Firefox')]

        br.open(self.libgenurl)
        br.select_form('libgen')
        input_form = self.title + self.author + self.publisher
        br.form['req'] = input_form
        ac = br.submit()
        html_from_page = ac
        soup = Soup(html_from_page, 'html.parser')
        links_table = soup.find_all('table')[3]
        table_data = []
        mirrors = []
        extensions = []
        for i in links_table:
            try:
                td = i.find_all('td')
                for tr in td:
                    # scrape mirror links
                    temp = tr.find('a', href=True)
                    mirror_page = temp['href']
                    # add also mirror link
                    if mirror_page.startswith('http') is False:
                        mirror_page = self.libgenurl + temp['href']
                    else:
                        mirror_page = temp['href']
                    mirrors.append(mirror_page)
            except Exception as e:
                    print(e)

            # Parse Details from table_data
            table = soup.find_all('table')[2]
            for i in table:
                try:
                    td = i.find_all('td')
                    row = tr.find_all('tr')
                    row = [tr.text for tr in td]
                    table_data.append(row)
                    extensions.append(row[8])
                    table_details = dict()
                    table_details['extensions'] = extensions
                    table_details['table_data'] = table_data
                    table_details['mirrors'] = mirrors
                    return table_details
                except Exception as e:
                    pass

                '''
                row = [tr.text for tr in td]
                table_data.append(row)
                extensions.append(row[8])
                table_details = dict()
                table_details['extensions'] = extensions
                table_details['table_data'] = table_data
                table_details['mirrors'] = mirrors
                print(table_details)
                return table_details
            else:
                print('\nNo results found or bad Internet connection.')
                print('Please,try again.') '''

    def give_result(self, extensions, table_data, mirrors, filetype):
        try:
            if filetype is not None:
                temp = 0
                for i in extensions:
                    if filetype == i:
                        result = dict()
                        result['url'] = mirrors[temp]
                        result['file'] = extensions[temp]
                        print("\nDownloading Link: FOUND")
                        return result
                    temp = temp + 1
            else:
                # return the first result
                result = dict()
                result['url'] = mirrors[0]
                result['file'] = extensions[0]
                print('\nDownloading Link: FOUND')
                return result
        except IndexError:
            print("Downloading Link:NOT FOUND\n")
            print('================================')

    def cursor(self, url, destination_folder,
               extension, forced):
        ''' asking the user to download a chosen book or to abort'''
        title = str(self.title)
        author = str(self.author)
        nameofbook = file_name(url)
        if nameofbook is None:
            nameofbook = title.replace('\n', '') + author.replace('\n', '') + '.' + extension
        if forced is not True:
            ask = confirm(f'Do you want to download:\n {nameofbook}')
            if ask is True:
                downloading(url, title, author, nameofbook, destination_folder,
                            extension)
        else:
            downloading(url, title, author, nameofbook, destination_folder,
                        extension)



from bookcut.book import book_find
from bookcut.mirror_checker import main as mirror_checker

def file_list(filename):
    '''checks if the input file is a .txt file and adds each separate line
       as a book to the list 'Lines'.
       After return this list to download_from_txt
    '''

    if filename.endswith('.txt'):
        try:
            file1 = open(filename, 'r', encoding='utf-8')
            Lines = file1.readlines()
            for i in Lines:
                if i == '\n':
                    Lines.remove(i)
            return Lines
        except FileNotFoundError:
            print('Error:No such file or directory:', filename)
    else:
        print("\nError:Not correct file type. Please insert a '.txt' file")


def booklist_main(file,destination,forced,extension):
    '''executes with the command --list'''
    Lines = file_list(file)
    if Lines is not None:
        print("List imported succesfully!")
        url = mirror_checker()
        if url is not None:
            temp = 1
            many = len(Lines)
            for a in Lines:
                if a != "":
                    print(f"~[{temp}/{many}] Searching for:", a,)
                    temp = temp + 1
                    book_find(a, '', '', destination, extension, forced, url)



import requests
import json
import re
from difflib import SequenceMatcher
import os
from bookcut.mirror_checker import openLibraryStatus

'''This file is used by ---allbooks command
   It is searching OpenLibrary for all books written from an
   author, and gives the choice to user to save it to a .txt file'''


def main(author, similarity):
    # returns all the books writen by an author from openlibrary
    # using similarity for filtering the results
    status = openLibraryStatus()
    if status is not False:
        search_url = "http://openlibrary.org/search.json?author=" + author
        jason = requests.get(search_url)
        jason = jason.text
        data = json.loads(jason)
        data = data['docs']
        if data != []:
            metr = 0
            books = []
            for i in range(0, len(data)-1):
                title = data[metr]['title']
                metr = metr + 1
                books.append(title)
                mylist = list(dict.fromkeys(books))

        #       Filtrering results: trying to erase similar titles
            words = [' the ', 'The ', ' THE ', ' The' ' a ', ' A ', ' and ',
                     ' of ', ' from ', 'on', 'The', 'in']

            noise_re = re.compile('\\b(%s)\\W'%('|'.join(map(re.escape, words))), re.I)
            clean_mylist = [noise_re.sub('', p) for p in mylist]

            for i in clean_mylist:
                for j in clean_mylist:
                    a = similar(i, j, similarity)
                    if a is True:
                        clean_mylist.pop(a)

            clean_mylist.sort()
            print(' ~Books found to OpenLibrary Database:\n')
            for i in clean_mylist:
                print(i)
            return clean_mylist
        else:
            print('(!) No valid author name, or bad internet connection.')
            print('Please try again!')
            return None


def similar(a, b, similarity):
    ''' function which check similarity between two strings '''
    ratio = SequenceMatcher(None, a, b).ratio()
    if ratio > similarity and ratio < 1:
        return True
    else:
        return False


def save_to_txt(lista, path, author):
    # save the books list to txt file.
    for content in lista:
        name = f'{author}_bibliography.txt'
        full_path = os.path.join(path, name)
        with open(full_path, 'a', encoding='utf-8') as f1:
            f1.write(content + ' ' + author + os.linesep)
    print('\nList saved at: ', full_path, '\n')



import click
import pyfiglet
from os import name, system
from bookcut.mirror_checker import main as mirror_checker
from bookcut.book import book_find
from bookcut.organise import main_organiser
from bookcut.search import search_downloader, link_finder, search
from bookcut.book_details import main as detailing
from bookcut.bibliography import main as allbooks
from bookcut.bibliography import save_to_txt
from bookcut.settings import initial_config, mirrors_append, read_settings
from bookcut.settings import screen_setting, print_settings, set_destination, path_checker
from bookcut.booklist import booklist_main


@click.group(name='commands')
@click.version_option(version="1.3.3")
def entry():
    """
    for a single book download you can \n
    bookcut.py book --bookname "White Fang" -- author "Jack London"
    \nor  bookcut.py book -b "White Fang" -a "Jack London" \n
*For a more complete help:  bookcut.py [COMMAND] --help\n
*For example: bookcut.py list --help
    """
    # read the settings ini file and check what value for clean screen
    settings = read_settings()
    clean_screen(settings[0])
    title = pyfiglet.figlet_format("BookCut")
    click.echo(title)
    click.echo('**********************************')
    print("Welcome to BookCut! I'm here to"
          '\nhelp you to read your favourite books!')
    print('**********************************')


@entry.command(name='list', help='Download a list of ebook from a .txt file')
@click.option('--file', '-f',
              help='A .txt file in which books are written in a separate line',
              required=True)
@click.option('--destination', '-d',
              help="The destinations folder of the downloaded books",
              default=path_checker())
@click.option('--forced',
              help='Forced option, accepts all books for downloading',
              is_flag=True)
@click.option('--extension', '-ext', help='File type of e-book.')
def download_from_txt(file, destination, forced, extension):
    click.echo('Importing of book list:Started.')
    if forced:
        click.echo(click.style('(!) Forced list downloading:Enabled', fg='green'))
    booklist_main(file, destination, forced, extension)


@entry.command(name='book', help="Download a book in epub format, by inserting"
               '\n the title and the author')
@click.option('--book', '-b', help="Title of Book", required=True)
@click.option('--author', '-a', help='The author of the Book', default=" ")
@click.option('--publisher', '-p', default='')
@click.option('--destination', '-d',
              help="The destinations folder of the downloaded books",
              default=path_checker())
@click.option('--extension', '-ext', help='Filetype of e-book for example:pdf')
@click.option('--forced', is_flag=True)
def book(book, author, publisher, destination, extension, forced):
    if author != ' ':
        click.echo(f'\nSearching for {book.capitalize()} by {author.capitalize()}')
    else:
        click.echo(f'\nSearching for {book.capitalize()}')
    url = mirror_checker()
    if url is not None:
        book_find(book, author, publisher, destination, extension, forced, url)


def clean_screen(setting):
    """ Cleans the terminal screen """
    if setting == 'True':
        if name == 'nt':
            _ = system('cls')
        else:
            _ = system('clear')


@entry.command(name='organise',
               help='Organise the ebooks in folders according\n to genre')
@click.option('--directory', '-d', help="Directory of source ", required=True,
              default=path_checker())
@click.option('--output', '-o',
              help="The destination folder of organised books",
              default=path_checker())
def organiser(directory, output):
    print("\nBookCut is starting to \norganise your books!")
    main_organiser(directory)


@entry.command(name='all-books',
               help="Search and return all the books from an author")
@click.option('--author', '-a', required=True, help='Author name')
@click.option('--ratio', '-r', help='Ratio for filtering  book results',
              default='0.7', type=float)
def bibliography(author, ratio):
    print(f'\nStart searching for all books by {author.capitalize()}:')
    lista = allbooks(author, ratio)
    if lista is not None:
        print('**********************************')
        choice = 'y or n'
        while choice != 'Y' or choice != 'N':
            choice = input('\nDo you wish to save the list? [Y/n]: ')
            choice = choice.capitalize()
            if choice == 'Y':
                save_to_txt(lista, path_checker(), author)
                break
            elif choice == 'N':
                print('Aborted.')
                break


@entry.command(name='search',
               help='Search LibGen and choose a book to download')
@click.option('--term', '-t', help='Term for searching')
def searching(term):
    print('Searching for:', term.capitalize())
    c = search(term)
    if c is not None:
        link = c[0]
        #### TODO: to erase
        mirror_used = mirror_checker()
        link = mirror_used + link
        print("First Link:", link)
        details = link_finder(link, mirror_used)
        filename = details[0]
        file_link = details[1]
        search_downloader(filename, file_link)


@entry.command(name='details', help='Search the details of a book')
@click.option('--book', '-b', help='Enter book & author or the ISBN number.',
              required=True, default=None)
def details(book):
    detailing(book)


@entry.command(name='config', help='BookCut configuration settings')
@click.option('--libgen_add', help="Add a Libgen mirror to mirrors list",
              default=None)
@click.option('--restore', help='Restores the settings file to initial state',
              is_flag=True)
@click.option('--settings', help='Prints the current BookCut settings',
              is_flag=True)
@click.option('--clean_screen', help='You can choose if BookCut will'
              ' clean terminal screen', is_flag=True)
@click.option('--download_folder', help="Set BookCut's download folder",
              default=None)
def configure_mode(restore, libgen_add, settings, clean_screen,
                   download_folder):
    if restore:
        prompt = click.confirm('\n Are you sure do you want to restore Settings?')
        if prompt is True:
            initial_config()
        else:
            click.echo('Aborted!')
    elif libgen_add is not None:
        click.echo(f'Adding {libgen_add} to mirrors list')
        mirrors_append(libgen_add)
    elif settings:
        print_settings()
    elif clean_screen:
        prompt = click.confirm('\nDo you want Bookcut to clean command line?')
        if prompt is True:
            screen_setting('True')
        else:
            screen_setting('False')
    elif download_folder is not None:
        set_destination(download_folder)
    else:
        print('Usage: bookcut config [OPTIONS]',
              "\nTry 'bookcut config --help' for help.\n",
              "\nError: Missing option or flag."
              )


if __name__ == '__main__':
    entry()



from bookcut.mirror_checker import openLibraryStatus
import os
import shutil
import requests
import json


def main_organiser(directory):
    status = openLibraryStatus()
    if status is not False:
        book_list = get_books(directory)
        # lists only the files in the given directory
        namepath = []
        with os.scandir(directory) as entries:
            for entry in entries:
                if entry.is_file():
                    namepath.append(entry.name)
        for i in range(0, len(book_list)):
            print("File:", namepath[i])
            try:
                ''' splitting file name to author and book title for using as
                    searching terms to OpenLibrary'''
                a = book_list[i].split('by')
                book = a[1]
                author = a[0]
                a = scraper(book, author)
                print("\n***", book, "  ", author)
                a = a['genre']
                filename = namepath[i]
                cutpaste(directory, a, filename)
            except IndexError:
                try:
                    a = book_list[i].split('-')
                    book = a[1]
                    author = a[0]
                    a = scraper(book, author)
                    print("\n***", book, "  ", author)
                    a = a['genre']
                    filename = namepath[i]
                    cutpaste(directory, a, filename)
                except IndexError:
                    print('Unable to organise this file.\n')
                    pass


def get_books(dir):
    ''' filtering epub, pdf, txt, mobi, djvu files in the given directory
        and return a list with all filenames '''
    epub_list = []
    for file in os.listdir(dir):
        if file.endswith(".epub"):
            renamed = file.replace('.epub', '')
            renamed = renamed.replace('_', " ")
            epub_list.append(renamed)
        elif file.endswith(".pdf"):
            renamed = file.replace('.pdf', '')
            renamed = renamed.replace('_', " ")
            epub_list.append(renamed)
        elif file.endswith('.txt'):
            renamed = file.replace('.txt', '')
            renamed = renamed.replace('_', " ")
            epub_list.append(renamed)
        elif file.endswith('.mobi'):
            renamed = file.replace('.mobi', '')
            renamed = renamed.replace('_', " ")
            epub_list.append(renamed)
        elif file.endswith('.djvu'):
            renamed = file.replace('.djvu', '')
            renamed = renamed.replace('_', " ")
            epub_list.append(renamed)
    return epub_list


def scraper(book, author):
        ''' parsing the book category from OpenLibrary '''
        try:
            book = book.replace(" ", '+')
            author = author.replace(" ", '+')

            search_url = "http://openlibrary.org/search.json?q=" + book + "+" + author
            jason = requests.get(search_url)
            jason = jason.text
            data = json.loads(jason)
            json_formatted_str = json.dumps(data, indent=2)

            book_values = {}
            isbn = None
            author_name = None
            title = None
            subject = None
            try:
                # TODO: to add feature to check all docs

                data = data['docs'][0]
            except IndexError:
                data = None
            if data is not None:
                try:
                    isbn = data['isbn'][0]
                except KeyError:
                    pass
                try:
                    author_name = data['author_name'][0]
                except KeyError:
                    pass
                try:
                    title = data['title_suggest']
                except KeyError:
                    pass
                try:
                    subject = data['subject']
                except KeyError:
                    pass

            book_values.update([('isbn', isbn), ('author', author_name),('title',title)])
            if subject is not None:
                for a in subject:
                    x = genre_finder(a)
                    if x is not None:
                        subject = x
                        break
                    else:
                        subject = 'Uncategorized'
            else:
                subject = 'Uncategorized'
            book_values.update({'genre': subject})
            return book_values
        except requests.ConnectionError:
            url = 'http://www.openlibrary.com'
            print('Unable to connect to:', url,
                  '\nPlease check your internet connection and try again later.')
            return None


def genre_finder(sub):
    genres = ['Classics', 'Literary', 'Fiction', 'Historical Fiction',
              'Romance', 'Horror', 'Mystery', 'Suspence', 'Fantasy', 'Action',
              'Adventure', 'Science Fiction', 'History', 'Biography',
              'Autobiography', 'Poetry', 'Art', 'Music', 'Humor', 'Religion',
              'Mythology', 'Philosophy', 'Health', 'Science', 'Social Science',
              'Psychology', 'Self-helf', 'Nonfiction']

    if sub in genres:
        return sub
    else:
        return None


def cutpaste(dir, genre, file):
    '''Check if genre folder exists if not it creates one'''
    path = os.path.join(dir, genre)
    if os.path.isdir(path):
        pass
    else:
        os.mkdir(path)
        print("Created folder:", genre)
        filepath = os.path.join(path, file)

    from_path = os.path.join(dir, file)
    dest_path = os.path.join(dir, genre, file)
    shutil.move(from_path, dest_path)
    print('File moved to: ', genre, '\n', '\n', "********************")



import configparser
import os
from bookcut.downloader import pathfinder


def initial_config():
    '''function to create settings .ini file, used also for restore settings'''
    try:
        write_config = configparser.ConfigParser()
        module_path = os.path.dirname(os.path.realpath(__file__))
        settings_ini = os.path.join(module_path, 'Settings.ini')

        write_config.add_section("LibGen")
        write_config.add_section("Settings")
        mirrors = "https://libgen.lc/,http://libgen.li/,http://185.39.10.101/,http://genesis.lib/"
        write_config.set("LibGen", "mirrors", mirrors)
        write_config.set("Settings", "clean_screen", 'True')
        write_config.set("Settings", "destination", "None")

        cfgfile = open(settings_ini, 'w')
        write_config.write(cfgfile)
        cfgfile.close()
    except PermissionError as error:
        print('\n', error)
        print('You have to be administrator to change BookCut settings. ')


def mirrors_append(url):
    '''function to append the LibGen mirrors list'''

    try:

        # READ EXISTING LIST
        config = configparser.ConfigParser()
        module_path = os.path.dirname(os.path.realpath(__file__))
        settings_ini = os.path.join(module_path, 'Settings.ini')

        config.read(settings_ini)
        mirrors = config.get("LibGen", "mirrors")
        mirrors = mirrors + ',' + url

        # APPEND LIST
        mirrors = str(mirrors)
        config.set("LibGen", "mirrors", mirrors)

        # WRITE TO INI FILE
        cfgfile = open(settings_ini, 'w')
        config.write(cfgfile)
        cfgfile.close()

        # Succefully message
        print('\nSuccesfully added to list!:')
        mirrors = mirrors.split(',')
        for i in mirrors:
            print(i)
    except PermissionError as error:
        print('\n', error)
        print('You have to be administrator to change BookCut settings. ')


def read_settings():
    # read the config file settings and printing them

    # get ini file path
    config = configparser.ConfigParser()
    module_path = os.path.dirname(os.path.realpath(__file__))
    settings_ini = os.path.join(module_path, 'Settings.ini')

    # get values
    config.read(settings_ini)
    clean_screen = config.get("Settings", "clean_screen")
    destination = config.get("Settings", "destination")
    settings = [clean_screen, destination]
    return settings


def print_settings():
    '''Prints settings'''
    settings = read_settings()

    print('\nBookCut Settings:\n')
    print('1.Clean Screen Option Enabled: ', settings[0])
    print('2.Destination Folder Path: ', settings[1])


def screen_setting(input):
    '''clean screen settings adjust'''
    try:
        config = configparser.ConfigParser()
        module_path = os.path.dirname(os.path.realpath(__file__))
        settings_ini = os.path.join(module_path, 'Settings.ini')

        config.read(settings_ini)
        config.set("Settings", "clean_screen", input)
        cfgfile = open(settings_ini, 'w')
        config.write(cfgfile)
        cfgfile.close()
    except PermissionError as error:
        print('\n', error)
        print('You have to be administrator to change BookCut settings. ')


def set_destination(path):
    try:
        if os.path.isdir(path):
            module_path = os.path.dirname(os.path.realpath(__file__))
            settings_ini = os.path.join(module_path, 'Settings.ini')

            config = configparser.ConfigParser()
            config.read(settings_ini)
            config.set("Settings", "destination", path)
            cfgfile = open(settings_ini, 'w')
            config.write(cfgfile)
            cfgfile.close()
            print('Destination path changed!\n', path)
        else:
            try:
                os.makedirs(path)
                print('Created folder: ', path)
            except FileNotFoundError as error:
                print('\n', error)
                print('(!) Not a valid path please try again!')

    except PermissionError as error:
        print('\n', error)
        print('(!) You have to be administrator to change BookCut settings!')


def path_checker():
    settings = read_settings()
    if settings[1] != 'None':
        return settings[1]
    else:
        path = pathfinder()
        return path


if __name__ == '__main__':
    initial_config()



import requests
import json
from requests import ConnectionError

'''This file is using by ---details command.
   It's main use is to search OpenLibrary for a books' details.
   It's input can be the name of the book or the ISBN.
'''


def main(term):
    # searching OpenLibrary and prints the details of a book
    try:
        if term is None:
            term =input("Please enter the book and the author, or the ISBN of the book.")
        term = term.replace(' ', '+')
        search_url = "http://openlibrary.org/search.json?q=" + term
        jason = requests.get(search_url)
        jason = jason.text
        data = json.loads(jason)
        try:
            data = data['docs'][0]
        except IndexError:
            data = None
            print('Invalid search, please try again.')

        if data is not None:
            author = data["author_name"][0]
            title = data['title_suggest']
            isbn = data['isbn']
            first_publish_year = data["first_publish_year"]
            try:
                lang = data['language']
            except KeyError:
                lang = None

            print("Results for search: ", term, '\n')
            print("Title:", title)
            print('Author(s):', author, '\n')
            print('ISBN(s):', isbn, '\n')
            if lang is not None:
                print('Language(s): ', )
            print('\nFirst published: ', first_publish_year)
    except ConnectionError:
        url = "http://www.openlibrary.com"
        print('Unable to connect to:', url,
              '\nPlease check your internet connection and try again later.')



from bs4 import BeautifulSoup as soupa
import requests


def epub_finder(soup):
    table = soup.find('table', attrs={'class': 'c'})
    tb = table.find_all('tr')
    data = []
    epub = "epub"
    for row in tb:
        col = row.find_all('td')
        col = [ele.text.strip() for ele in col]
        xxx = [ele for ele in col if ele]

        false_results = ['[1]', '[2]', '[3]', '[4]', '[5]']
        if false_results == xxx:
            pass
        else:
            data.append(xxx)
    del data[0]
    count = 0
    for a in data:
        if epub in a:
            break
        else:
            count = count + 1
    return count


def file_name(url):
    print('URL: ',url)
    page = requests.get(url)
    try:
        soup = soupa(page.content, 'html.parser')
        r = soup.find('input')['value']
        r.replace('\n', '')
        return r
    except TypeError:
        return None



import setuptools
import sys
import pathlib

if sys.version_info.major < 3:
    print("\nPython 2 is not supported! \nPlease upgrade to Python 3.\n")
    print("Installation of BookCut stopped, please try again with\n"
          'a newer version of Python!')
    sys.exit(1)

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setuptools.setup(
    name="BookCut",
    python_requires='>3.5.2',
    version="1.3.4",
    author="Costis94",
    author_email="gravitymusician@gmail.com",
    description="Command Line Interface app to download ebooks",
    long_description_content_type="text/markdown",
    long_description=README,
    url="https://github.com/costis94/bookcut",
    packages=setuptools.find_packages(),
    classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
    install_requires=[
            'pandas',
            'click>=7.1.2',
            'requests',
            'beautifulsoup4',
            'pyfiglet',
            'tqdm',
            'mechanize'],
    include_package_data=True,
    entry_points='''
            [console_scripts]
            bookcut=bookcut.bookcut:entry
            ''',


        )



import requests
from requests import ConnectionError
import configparser
import os


def main():
    '''Check which LibGen mirror is available'''

    config = configparser.ConfigParser()
    module_path = os.path.dirname(os.path.realpath(__file__))
    settings_ini = os.path.join(module_path, 'Settings.ini')
    config.read(settings_ini)
    mirrors = config.get("LibGen", "mirrors")
    mirrors = mirrors.split(',')

    for url in mirrors:
        try:
            r = requests.head(url)
            if r.status_code == 200 or r.status_code == 301:
                status = True
            if status is True:
                print('Connected to:', url)
                return url
                break
            else:
                print("No mirrors available or no Internet Connection!")
        except:
            pass


def openLibraryStatus():
    try:
        url = 'http://www.openlibrary.org'
        request = requests.head(url)
        if request.status_code == 200 or request.status_code == 301:
            print('Connected to:', url)
        else:
            print('Unable to connect to:', url,
                  '\nPlease check your internet connection and try again later.')
            return False
    except ConnectionError:
        print('\nUnable to connect to:', url,
              '\nPlease check your internet connection and try again later.')
        return False


if __name__ == '__main__':
    main()
